==> openliberty-runtime-20.0.0.3.zip: OSGI-INF/welcome/nls/pt-br/messages.js <==
var messages = {
    WELCOME_SECTION: "Seção de boas-vindas",
    WELCOME_SECTION_CONTENT: "Conteúdo da seção de boas-vindas",
    WELCOME_MESSAGE: "Bem-vindo aos ",
    WELCOME_IBM_OPEN_SOURCE: "Um projeto de software livre IBM",
    WELCOME_LIGHTWEIGHT: "Uma estrutura aberta leve para a construção e execução de microsserviços Java nativos de nuvem rápidos e eficientes.",
    UFO: "UFO e feixe",
    CLOUDS: "Nuvens",
    LOGOS_SECTION: "Seção de logotipos",
    COMPATIBLE: "O Open Liberty é uma implementação compatível de:",
    MICROPROFILE: "Logotipo do MicroProfile",
    JAKARTA_EE: "Logotipo do Jakarta EE",
    RESOURCES_SECTION: "Seção de Recursos",
    RESOURCES: "Recursos e Ajuda",
    GITHUB: "Logotipo do GitHub",
    TWITTER: "Logotipo do Twitter",
    GITTER: "Logotipo do Gitter",
    STACK_OVERFLOW: "Logotipo do Estouro de pilha",
    GROUPS_IO: "Logotipo do Groups.io",
    OL_SUPPORT: "Logotipo do Open Liberty",
    DOCS: "Documentos", // Translate 'Documentation'
    COPYRIGHT: "copyright",
    OPEN_LIBERTY_FOOTER: "Logotipo do rodapé do Liberty",
    COPYRIGHT_OPEN_LIBERTY: "Licensed Materials — Property of the Open Liberty project, Copyright IBM Corp and others 1997, 2019. O projeto é distribuído sob os termos do Eclipse Public License v1.", // COPYRIGHT_URL
    UPDATE_BANNER_SECTION: "Seção de atualização de banner",
    UPDATE_BANNER_SECTION_CONTENT: "Conteúdo da seção de atualização de banner",
    HEADER_UPDATE_AVAILABLE: "Atualização disponível: ",
    HEADER_DOWNLOAD_LINK: "Clique para fazer download {0}", // Product name
    HEADER_UPDATE_AVAILABLE_DOWNLOAD_LINK: "Atualização disponível. Clique para fazer download {0}", // Product name
    UPDATE_BANNER_CLOSE_BUTTON: "Fechar banner de atualização",
    CONTEXT_ROOT_NOT_FOUND: "Raiz de contexto não encontrada"
};

==> openliberty-runtime-21.0.0.10.zip: OSGI-INF/welcome/nls/pt-br/messages.js <==
var messages = {
    WELCOME_SECTION: "Seção de boas-vindas",
    WELCOME_SECTION_CONTENT: "Conteúdo da seção de boas-vindas",
    WELCOME_MESSAGE: "Bem-vindo ao ",
    WELCOME_IBM_OPEN_SOURCE: "Um projeto de software livre IBM",
    WELCOME_LIGHTWEIGHT: "Uma estrutura aberta leve para o desenvolvimento e a execução de microsserviços Java nativos de nuvem rápidos e eficientes.",
    UFO: "UFO e feixe",
    CLOUDS: "Nuvens",
    LOGOS_SECTION: "Seção de logotipos",
    COMPATIBLE: "O Open Liberty é uma implementação compatível de:",
    MICROPROFILE: "Logotipo do MicroProfile",
    JAKARTA_EE: "Logotipo do Jakarta EE",
    RESOURCES_SECTION: "Seção de Recursos",
    RESOURCES: "Recursos e Ajuda",
    GITHUB: "Logotipo do GitHub",
    TWITTER: "Logotipo do Twitter",
    GITTER: "Logotipo do Gitter",
    STACK_OVERFLOW: "Logotipo do Estouro de pilha",
    GROUPS_IO: "Logotipo do Groups.io",
    OL_SUPPORT: "Logotipo do Open Liberty",
    DOCS: "Documentos", // Translate 'Documentation'
    COPYRIGHT: "copyright",
    OPEN_LIBERTY_FOOTER: "Logotipo do rodapé do Liberty",
    COPYRIGHT_OPEN_LIBERTY: "Licensed Materials — Property of the Open Liberty project, Copyright IBM Corp and others 1997, 2019. O projeto é distribuído sob os termos do Eclipse Public License v1.", // COPYRIGHT_URL
    UPDATE_BANNER_SECTION: "Seção de atualização de banner",
    UPDATE_BANNER_SECTION_CONTENT: "Conteúdo da seção de atualização de banner",
    HEADER_UPDATE_AVAILABLE: "Atualização disponível: ",
    HEADER_DOWNLOAD_LINK: "Clique para fazer o download do {0}", // Product name
    HEADER_UPDATE_AVAILABLE_DOWNLOAD_LINK: "Atualização disponível. Clique para fazer o download do {0}", // Product name
    UPDATE_BANNER_CLOSE_BUTTON: "Fechar banner de atualização",
    CONTEXT_ROOT_NOT_FOUND: "Raiz de contexto não encontrada"
};
